@@ -28,7 +28,8 @@ from .provider import Suburb, Municipality, Provider, Province, ProviderError, S
 
 class AreaInfo:
     def __init__(self, /, **kwargs):
-        self.province = Province(**kwargs.get("Province", {}))
+        province = kwargs.get("Province", {})
+        self.province = Province(province.get("Id"))
         self.municipality = Municipality(**kwargs.get("Municipality", {}))
         self.suburb = Suburb(**kwargs.get("Suburb", {}), municipality=self.municipality.name, province=self.province.name)
         self.period = kwargs.get("Period")
@@ -47,17 +48,15 @@ class Suburb(Suburb):
         self.municipality = Municipality(name=kwargs.get("MunicipalityName"))
         self.province = Eskom.province_from_name(kwargs.get("ProvinceName"))
         self.total = kwargs.get("Total")
-        super().__init__(**kwargs)
 
 
 class Municipality(Municipality):
     def __init__(self, /, **kwargs):
         self.id = kwargs.get("Value", kwargs.get("Id"))
-        self.name = kwargs.get("Text", kwargs.get("Name"))
+        self.name = kwargs.get("Text", kwargs.get("Name", kwargs.get("name")))
         self.selected = kwargs.get("Selected")
         self.group = kwargs.get("Group")
         self.disabled = kwargs.get("Disabled")
-        super().__init__(**kwargs)
 
 
 # TODO: Improve error handling when Eskom responds with an error.
@@ -84,7 +83,7 @@ class Eskom(Provider):
             "9": Stage.STAGE_8,
         }.get(status, Stage.UNKNOWN)
 
-    def find_suburbs(self, search_text: str, max_results: int = 300) -> List[Suburb]:
+    def find_suburbs(self, search_text: str, max_results: int = 10) -> List[Suburb]:
         url = "{base_url}/FindSuburbs?searchText={search_text}&maxResults={max_results}".format(
             base_url=self.base_url,
             search_text=search_text,
@@ -96,7 +95,7 @@ class Eskom(Provider):
     def get_municipalities(self, province: Province) -> List[Municipality]:
         url = "{base_url}/GetMunicipalities/?Id={province}".format(
             base_url=self.base_url,
-            province=province,
+            province=province.value,
         )
         data = _get_response(url)
         return json.loads(data, object_hook=lambda d: Municipality(**d))
